@@ -2,6 +2,7 @@ print.matchessuf <-
   function(x, ...)
   {
     for (b in 1:length(x)) {
-    cat(x[[b]]$FocConj, ':\n----------\n')
+    cat(x[[b]]$title, ':\n----------\n')
     print(x[[b]]$results)
     cat('\n') }}  
+
